@@ -1,5 +1,5 @@
 /*  Clzip - LZMA lossless data compressor
-    Copyright (C) 2010-2018 Antonio Diaz Diaz.
+    Copyright (C) 2010-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -325,7 +325,7 @@ static int LZe_sequence_optimizer( struct LZ_encoder * const e,
         --prev_index;
       else					/* prev_index2 >= 0 */
         prev_index = prev_index2;
-      cur_state = 8;				/* St_set_char_rep(); */
+      cur_state = St_set_char_rep();
       }
     cur_trial->state = cur_state;
     for( i = 0; i < num_rep_distances; ++i )
@@ -496,7 +496,7 @@ bool LZe_encode_member( struct LZ_encoder * const e,
                         const unsigned long long member_size )
   {
   const unsigned long long member_size_limit =
-    member_size - Ft_size - max_marker_size;
+    member_size - Lt_size - max_marker_size;
   const bool best = ( e->match_len_limit > 12 );
   const int dis_price_count = best ? 1 : 512;
   const int align_price_count = best ? 1 : dis_align_size;
@@ -510,7 +510,7 @@ bool LZe_encode_member( struct LZ_encoder * const e,
   for( i = 0; i < num_rep_distances; ++i ) reps[i] = 0;
 
   if( Mb_data_position( &e->eb.mb ) != 0 ||
-      Re_member_position( &e->eb.renc ) != Fh_size )
+      Re_member_position( &e->eb.renc ) != Lh_size )
     return false;				/* can be called only once */
 
   if( !Mb_data_finished( &e->eb.mb ) )		/* encode first byte */
