@@ -1,5 +1,5 @@
 /*  Clzip - LZMA lossless data compressor
-    Copyright (C) 2010-2018 Antonio Diaz Diaz.
+    Copyright (C) 2010-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -237,7 +237,7 @@ struct Range_encoder
   unsigned ff_count;
   int outfd;			/* output file descriptor */
   uint8_t cache;
-  File_header header;
+  Lzip_header header;
   };
 
 void Re_flush_data( struct Range_encoder * const renc );
@@ -273,8 +273,8 @@ static inline void Re_reset( struct Range_encoder * const renc,
   renc->range = 0xFFFFFFFFU;
   renc->ff_count = 0;
   renc->cache = 0;
-  Fh_set_dictionary_size( renc->header, dictionary_size );
-  for( i = 0; i < Fh_size; ++i )
+  Lh_set_dictionary_size( renc->header, dictionary_size );
+  for( i = 0; i < Lh_size; ++i )
     Re_put_byte( renc, renc->header[i] );
   }
 
@@ -284,7 +284,7 @@ static inline bool Re_init( struct Range_encoder * const renc,
   renc->buffer = (uint8_t *)malloc( re_buffer_size );
   if( !renc->buffer ) return false;
   renc->outfd = ofd;
-  Fh_set_magic( renc->header );
+  Lh_set_magic( renc->header );
   Re_reset( renc, dictionary_size );
   return true;
   }
