@@ -1,5 +1,5 @@
 /*  Clzip - LZMA lossless data compressor
-    Copyright (C) 2010-2018 Antonio Diaz Diaz.
+    Copyright (C) 2010-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,14 +74,14 @@ bool FLZe_encode_member( struct FLZ_encoder * const fe,
                          const unsigned long long member_size )
   {
   const unsigned long long member_size_limit =
-    member_size - Ft_size - max_marker_size;
+    member_size - Lt_size - max_marker_size;
   int rep = 0, i;
   int reps[num_rep_distances];
   State state = 0;
   for( i = 0; i < num_rep_distances; ++i ) reps[i] = 0;
 
   if( Mb_data_position( &fe->eb.mb ) != 0 ||
-      Re_member_position( &fe->eb.renc ) != Fh_size )
+      Re_member_position( &fe->eb.renc ) != Lh_size )
     return false;				/* can be called only once */
 
   if( !Mb_data_finished( &fe->eb.mb ) )		/* encode first byte */
