@@ -1,5 +1,5 @@
 /*  Clzip - LZMA lossless data compressor
-    Copyright (C) 2010-2018 Antonio Diaz Diaz.
+    Copyright (C) 2010-2019 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,16 +33,16 @@ int FLZe_longest_match_len( struct FLZ_encoder * const fe, int * const distance
 
 static inline void FLZe_update_and_move( struct FLZ_encoder * const fe, int n )
   {
+  struct Matchfinder_base * const mb = &fe->eb.mb;
   while( --n >= 0 )
     {
-    if( Mb_available_bytes( &fe->eb.mb ) >= 4 )
+    if( Mb_available_bytes( mb ) >= 4 )
       {
-      fe->key4 = ( ( fe->key4 << 4 ) ^ fe->eb.mb.buffer[fe->eb.mb.pos+3] ) &
-                 fe->eb.mb.key4_mask;
-      fe->eb.mb.pos_array[fe->eb.mb.cyclic_pos] = fe->eb.mb.prev_positions[fe->key4];
-      fe->eb.mb.prev_positions[fe->key4] = fe->eb.mb.pos + 1;
+      fe->key4 = ( ( fe->key4 << 4 ) ^ mb->buffer[mb->pos+3] ) & mb->key4_mask;
+      mb->pos_array[mb->cyclic_pos] = mb->prev_positions[fe->key4];
+      mb->prev_positions[fe->key4] = mb->pos + 1;
       }
-    Mb_move_pos( &fe->eb.mb );
+    Mb_move_pos( mb );
     }
   }
 
